# gimad

Data migration tool for PostgreSQL

## Config

Configurations are stored in `gimad.json`. They can be overridden using environment variables. For
example, the option `db_url` in `gimad.json` can be overridden by defining the environment variables
`GIMAD_DB_URL`.
